cmoncrawl.processor.pipeline.extractor
======================================

.. automodule:: cmoncrawl.processor.pipeline.extractor

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autoclass:: BaseExtractor
      :members:

   .. autoclass:: DomainRecordExtractor
      :members:

   .. autoclass:: HTMLExtractor
      :members:

   .. autoclass:: IExtractor
      :members:

   .. autoclass:: PageExtractor
      :members:


   
   
   



